==> azure_mgmt_cosmosdb-0.2.0.crate: azure_mgmt_cosmosdb-0.2.0/README.md <==
# azure_mgmt_cosmosdb crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/cosmos-db/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-preview-2021-11`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-preview-2021-11` has 207 operations from 1 API versions: `2021-11-15-preview`. Use crate feature `package-preview-2021-11` to enable. The operations will be in the `package_preview_2021_11` module.
- `package-2021-10` has 168 operations from 1 API versions: `2021-10-15`. Use crate feature `package-2021-10` to enable. The operations will be in the `package_2021_10` module.
- `package-preview-2021-10` has 200 operations from 1 API versions: `2021-10-15-preview`. Use crate feature `package-preview-2021-10` to enable. The operations will be in the `package_preview_2021_10` module.
- `package-2021-07-preview` has 183 operations from 1 API versions: `2021-07-01-preview`. Use crate feature `package-2021-07-preview` to enable. The operations will be in the `package_2021_07_preview` module.
- `package-2021-06` has 150 operations from 1 API versions: `2021-06-15`. Use crate feature `package-2021-06` to enable. The operations will be in the `package_2021_06` module.
- `package-2021-05` has 140 operations from 1 API versions: `2021-05-15`. Use crate feature `package-2021-05` to enable. The operations will be in the `package_2021_05` module.
- `package-2021-04` has 140 operations from 1 API versions: `2021-04-15`. Use crate feature `package-2021-04` to enable. The operations will be in the `package_2021_04` module.
- `package-2021-04-preview` has 171 operations from 1 API versions: `2021-04-01-preview`. Use crate feature `package-2021-04-preview` to enable. The operations will be in the `package_2021_04_preview` module.
- `package-2021-03` has 132 operations from 1 API versions: `2021-03-15`. Use crate feature `package-2021-03` to enable. The operations will be in the `package_2021_03` module.
- `package-2021-03-preview` has 166 operations from 1 API versions: `2021-03-01-preview`. Use crate feature `package-2021-03-preview` to enable. The operations will be in the `package_2021_03_preview` module.
- `package-preview-2021-04` has 167 operations from 1 API versions: `2021-04-01-preview`. Use crate feature `package-preview-2021-04` to enable. The operations will be in the `package_preview_2021_04` module.
- `package-2021-01` has 132 operations from 1 API versions: `2021-01-15`. Use crate feature `package-2021-01` to enable. The operations will be in the `package_2021_01` module.
- `package-2020-09` has 132 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-09-01`. Use crate feature `package-2020-09` to enable. The operations will be in the `package_2020_09` module.
- `package-2020-06-preview` has 131 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-06-01-preview`. Use crate feature `package-2020-06-preview` to enable. The operations will be in the `package_2020_06_preview` module.
- `package-2020-04` has 132 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-04-01`. Use crate feature `package-2020-04` to enable. The operations will be in the `package_2020_04` module.
- `package-2020-03` has 132 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-03-01`. Use crate feature `package-2020-03` to enable. The operations will be in the `package_2020_03` module.
- `package-2019-12` has 114 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2019-12-12`. Use crate feature `package-2019-12` to enable. The operations will be in the `package_2019_12` module.
- `package-2019-08` has 108 operations from 1 API versions: `2019-08-01`. Use crate feature `package-2019-08` to enable. The operations will be in the `package_2019_08` module.
- `package-2019-08-preview` has 114 operations from 2 API versions: `2019-08-01`, `2019-08-01-preview`. Use crate feature `package-2019-08-preview` to enable. The operations will be in the `package_2019_08_preview` module.
- `package-2015-04` has 89 operations from 1 API versions: `2015-04-08`. Use crate feature `package-2015-04` to enable. The operations will be in the `package_2015_04` module.
- `package-2014-04` has 89 operations from 1 API versions: `2015-04-01`. Use crate feature `package-2014-04` to enable. The operations will be in the `package_2014_04` module.
- `package-2015-11` has 89 operations from 1 API versions: `2015-11-06`. Use crate feature `package-2015-11` to enable. The operations will be in the `package_2015_11` module.
- `package-2016-03-19` has 89 operations from 1 API versions: `2016-03-19`. Use crate feature `package-2016-03-19` to enable. The operations will be in the `package_2016_03_19` module.
- `package-2016-03-31` has 89 operations from 1 API versions: `2016-03-31`. Use crate feature `package-2016-03-31` to enable. The operations will be in the `package_2016_03_31` module.

==> azure_mgmt_cosmosdb-0.3.0.crate: azure_mgmt_cosmosdb-0.3.0/README.md <==
# azure_mgmt_cosmosdb crate

This is a generated [Azure SDK for Rust](https://github.com/Azure/azure-sdk-for-rust) crate from the Azure REST API specifications listed in:

https://github.com/Azure/azure-rest-api-specs/blob/main/specification/cosmos-db/resource-manager/readme.md

To get started with these generated service crates, see the [examples](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/README.md#examples).

The default tag is `package-preview-2022-02`.

The following [tags](https://github.com/Azure/azure-sdk-for-rust/blob/main/services/tags.md) are available:

- `package-preview-2022-02` has 216 operations from 1 API versions: `2022-02-15-preview`. Use crate feature `package-preview-2022-02` to enable. The operations will be in the `package_preview_2022_02` module.
- `package-preview-2021-11` has 207 operations from 1 API versions: `2021-11-15-preview`. Use crate feature `package-preview-2021-11` to enable. The operations will be in the `package_preview_2021_11` module.
- `package-2021-10` has 168 operations from 1 API versions: `2021-10-15`. Use crate feature `package-2021-10` to enable. The operations will be in the `package_2021_10` module.
- `package-preview-2021-10` has 200 operations from 1 API versions: `2021-10-15-preview`. Use crate feature `package-preview-2021-10` to enable. The operations will be in the `package_preview_2021_10` module.
- `package-2021-07-preview` has 183 operations from 1 API versions: `2021-07-01-preview`. Use crate feature `package-2021-07-preview` to enable. The operations will be in the `package_2021_07_preview` module.
- `package-2021-06` has 150 operations from 1 API versions: `2021-06-15`. Use crate feature `package-2021-06` to enable. The operations will be in the `package_2021_06` module.
- `package-2021-05` has 140 operations from 1 API versions: `2021-05-15`. Use crate feature `package-2021-05` to enable. The operations will be in the `package_2021_05` module.
- `package-2021-04` has 140 operations from 1 API versions: `2021-04-15`. Use crate feature `package-2021-04` to enable. The operations will be in the `package_2021_04` module.
- `package-2021-04-preview` has 171 operations from 1 API versions: `2021-04-01-preview`. Use crate feature `package-2021-04-preview` to enable. The operations will be in the `package_2021_04_preview` module.
- `package-2021-03` has 132 operations from 1 API versions: `2021-03-15`. Use crate feature `package-2021-03` to enable. The operations will be in the `package_2021_03` module.
- `package-2021-03-preview` has 166 operations from 1 API versions: `2021-03-01-preview`. Use crate feature `package-2021-03-preview` to enable. The operations will be in the `package_2021_03_preview` module.
- `package-preview-2021-04` has 167 operations from 1 API versions: `2021-04-01-preview`. Use crate feature `package-preview-2021-04` to enable. The operations will be in the `package_preview_2021_04` module.
- `package-2021-01` has 132 operations from 1 API versions: `2021-01-15`. Use crate feature `package-2021-01` to enable. The operations will be in the `package_2021_01` module.
- `package-2020-09` has 132 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-09-01`. Use crate feature `package-2020-09` to enable. The operations will be in the `package_2020_09` module.
- `package-2020-06-preview` has 131 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-06-01-preview`. Use crate feature `package-2020-06-preview` to enable. The operations will be in the `package_2020_06_preview` module.
- `package-2020-04` has 132 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-04-01`. Use crate feature `package-2020-04` to enable. The operations will be in the `package_2020_04` module.
- `package-2020-03` has 132 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2020-03-01`. Use crate feature `package-2020-03` to enable. The operations will be in the `package_2020_03` module.
- `package-2019-12` has 114 operations from 3 API versions: `2019-08-01`, `2019-08-01-preview`, `2019-12-12`. Use crate feature `package-2019-12` to enable. The operations will be in the `package_2019_12` module.
- `package-2019-08` has 108 operations from 1 API versions: `2019-08-01`. Use crate feature `package-2019-08` to enable. The operations will be in the `package_2019_08` module.
- `package-2019-08-preview` has 114 operations from 2 API versions: `2019-08-01`, `2019-08-01-preview`. Use crate feature `package-2019-08-preview` to enable. The operations will be in the `package_2019_08_preview` module.
- `package-2015-04` has 89 operations from 1 API versions: `2015-04-08`. Use crate feature `package-2015-04` to enable. The operations will be in the `package_2015_04` module.
- `package-2014-04` has 89 operations from 1 API versions: `2015-04-01`. Use crate feature `package-2014-04` to enable. The operations will be in the `package_2014_04` module.
- `package-2015-11` has 89 operations from 1 API versions: `2015-11-06`. Use crate feature `package-2015-11` to enable. The operations will be in the `package_2015_11` module.
- `package-2016-03-19` has 89 operations from 1 API versions: `2016-03-19`. Use crate feature `package-2016-03-19` to enable. The operations will be in the `package_2016_03_19` module.
- `package-2016-03-31` has 89 operations from 1 API versions: `2016-03-31`. Use crate feature `package-2016-03-31` to enable. The operations will be in the `package_2016_03_31` module.
